@@ -16,7 +16,7 @@ from .common import PyPy
 
 @add_metaclass(abc.ABCMeta)
 class PyPy2(PyPy, Python2):
-    """"""
+    """ """
 
     @classmethod
     def exe_stem(cls):
@@ -31,6 +31,10 @@ class PyPy2(PyPy, Python2):
         if host_include_marker.exists():
             yield PathRefToDest(host_include_marker.parent, dest=lambda self, _: self.include)
 
+    @classmethod
+    def needs_stdlib_py_module(cls):
+        return True
+
     @classmethod
     def host_include_marker(cls, interpreter):
         return Path(interpreter.system_include) / "PyPy.h"
@@ -108,7 +112,7 @@ class Pypy2Windows(PyPy2, WindowsSupports):
 
     @classmethod
     def _shared_libs(cls):
-        return ["libpypy-c.dll"]
+        return ["libpypy-c.dll", "libffi-7.dll"]
 
     @classmethod
     def sources(cls, interpreter):
